(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     56870,       1918]*)
(*NotebookOutlinePosition[     99845,       2983]*)
(*  CellTagsIndexPosition[     98872,       2945]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Operator Linear Algebra Package",
    FontFamily->"Comic Sans MS",
    FontSlant->"Italic",
    FontColor->RGBColor[0.0156252, 0.0820325, 0.671885]],
  "\n\n",
  StyleBox["Author:  ", "Section",
    FontColor->RGBColor[0.277348, 0.542977, 0.503914]],
  StyleBox["\n\n", "Section"],
  StyleBox["Liu Zhao\nInstitute of Modern Physics\nNorthwest University\n\
Xian, China\n\nsend comments, suggestions etc to:\nlzhao@phy.nwu.edu.cn", 
    "Text",
    FontFamily->"MS Serif",
    FontSize->12,
    FontSlant->"Italic",
    FontColor->GrayLevel[0.333333]]
}], "Title",
  CellDingbat->None,
  CellTags->"copynotice"],

Cell[CellGroupData[{

Cell["Disclaimer", "Section",
  CellTags->"Disclaimer"],

Cell["\<\
This software package is provided as is. No warranty of any kind is provided. \
The author is not liable for any damage caused directly or indirectly by \
using this software package. The author also does not guarantee the \
correctness of this software, which means that he does not guarantee you get \
the correct result even if you use the software correctly.

This package can be freely copied and/or redistributed without written \
permition of the author, provided you keep the package as a whole, and that \
you do so only for educational purposes. You may also modify/improve the \
source code to meet your need. In that case the author would like to receive \
an improved copy of your code. If you plan to use the package for any other \
purposes than described above, contact and discuss with me.
\
\>", "Text",
  CellTags->"Disclaimer"],

Cell[TextData[{
  StyleBox["Mathematica", "Text",
    FontSlant->"Italic"],
  StyleBox["@ is the Trade Mark of Wolfram Research Inc.  ", "Text"]
}], "Text",
  CellTags->"Disclaimer"]
}, Closed]],

Cell[CellGroupData[{

Cell["About the Package - What's it for?", "Section",
  CellTags->"Introduction"],

Cell[TextData[{
  "Though ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as well as many other general purpose computer algebra systems has made \
considerable achievements in symbolic computations in commuting algebraic \
objects, relatively little support for noncommutative (operator-valued) \
evaluations. And in practice, such operator-valued objects are of central \
importance in certain disciplines which makes the application of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in those disciplines a troublesome task, if not impossible.\n\nGeneral \
purpose computer algebra systems like ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", however, do have limited support to noncommutative algebraic \
calculations. The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " system provides the function ",
  StyleBox["NonCommutativeMultiply",
    FontWeight->"Bold"],
  ", for instance, which is greatly enhanced by the NonCommutativeAlgebra \
Package (freely available on the ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " web site) by J.William Helton, Mark Stankus and Robert L. Miller. That \
package, in turn, is a fairly complete noncommutative algebra package under \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", though the authors originally developed it with the aim of application \
in control theory.\n\nThe present package is an alternative choice of \
noncommutative algebra package for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". In contrast to the huge NCAlgebra package, this package is relatively \
very small and it bears a different aim - aiming at application in quantum \
theories of physics, especially in certain fields as integrable models and 2d \
statistical mechanics. Consequently, this package contains a number of \
functionalities which are either missing in the NCAlgebra package or greatly \
enhances the functionality of the corresponding functions in the NCAlgebra \
package. Of cause, there are also a lot of functions which are present in \
NCAlgebra but are missing here. Therefore, your choice of either NCAlgebra or \
the present package is determined by your concrete purposes. In practice if \
you fail to find some functionality in one of these packages, there is a \
chance to get it in the other. Good luck."
}], "Text",
  CellTags->"Introduction"]
}, Closed]],

Cell[CellGroupData[{

Cell["An introduction of the Package", "Section",
  CellTags->"Tour"],

Cell[CellGroupData[{

Cell["Installing the Package", "Subsection",
  CellTags->{"Tour", "install"}],

Cell[TextData[{
  "If you are reading this text from within the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Help Browser, then you have already installed the package properly. \
Otherwise,\n\[EmptySmallSquare]  ",
  StyleBox["If you are Microsoft Windows 9x user",
    FontVariations->{"Underline"->True}],
  ", unpack the zipped archive of the package in the folder \n    ...\\AddOns\
\\Application \n    Then from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Frontend, choose the Help menu and click the menuitem \"Rebuild Help \
Index\".\n\[EmptySmallSquare]  ",
  StyleBox["If you are Unix user and have the root previledge",
    FontVariations->{"Underline"->True}],
  ", unpack the package files in the directory \n    .../AddOns/Application\n \
   Then from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Frontend, choose the Help menu and click the menuitem \"Rebuild Help \
Index\".\n\[EmptySmallSquare]  ",
  StyleBox["If you are Unix user and have not the root preveledge",
    FontVariations->{"Underline"->True}],
  ", then you can choose either one of the following two ways:\n    A.  Ask \
the root user to install this package as described as above;\n    B.  Unpack \
the package in your home directory and in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, issue the command\n          SetDirectory[\"(your home \
directory)\"]\n          This way you can use this package by explicitly \
issuing the Loadpackage command like \n          <<(homedir)/  OPScalar.m\n   \
       But you'll not be able to install the Help file. However you can \
always read the manual as a normal notebook.\n\[EmptySmallSquare]  ",
  StyleBox["If you are using operation systems other than Windows and Unix,",
    FontVariations->{"Underline"->True}],
  " you are on you own. The author does not \n    have access to those \
systems and so have no idea on the installation over those systems. Hopefully \
following \n    the standard way of installing ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages under that particular system, you'll make a success."
}], "Text",
  CellTags->{"install", "Tour"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading the Package", "Subsection",
  CellTags->{"Tour", "load"}],

Cell["\<\
There are several ways to load the package. First of all, if you have \
instlled the package as a Win 9x user or as root under Unix, you can issue \
the command \
\>", "Text",
  CellTags->{"load", "Tour"}],

Cell[BoxData[
    \(<< OPLinearAlgebra`\)], "Input",
  CellTags->{"load", "Tour"}],

Cell[TextData[{
  "at the very first of your ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. You can also put this line into your system init.m file so that \
every time the kernel is started, it automatically loads the package into \
memory.\n\nThe second way of loading the package is to load an individual \
subpackage each time explicitly. This is also the way for non-root Unix \
users.\n\nThe third way is to make use of the Palettes provoded by the \
package. However, for non-root Unix users, the Palettes notebook files has to \
be edited explitly using a text editor to reflect the correct directory in \
which the package is installed."
}], "Text",
  CellTags->{"load", "Tour"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Reload the package", "Subsection",
  CellTags->{"Tour", "reload"}],

Cell[TextData[{
  "It should be reminded that all subpackages of this software package is \
developed in such a manner that if any one of them is reloaded into the \
memory, the functions defined in that specific subpackage is automatically \
cleared and redefined. This way of implementing the functions avoids \
ocational conflicts (sometimes infinite loops) in the memory, but it might be \
harmeful if you have added new definitions to the existing functions during \
the session. It is particularly important to take a notice if the subpackage \
",
  StyleBox["OPScalar",
    FontWeight->"Bold"],
  " is reloaded, since it automatically clears all the mode switches you have \
modified and restores the default status. The definition of operators, \
however, is an exception to this machanism: the system automatically \
remembers the declared basic operators so that they do not need to be \
redeclared after the package reloads.  "
}], "Text",
  CellTags->{"Tour", "reload"}]
}, Closed]],

Cell[CellGroupData[{

Cell["The Palettes", "Subsection",
  CellTags->{"Tour", "palettes"}],

Cell[TextData[{
  "To accelerate the input of several key functions in the package, a \
modified version of the system's palette BasicInput, called OPBasicInput, is \
included with the package files. This should be placed in the systems palette \
directory if you wish to load the palette as while ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " starts. "
}], "Text",
  CellTags->{"palettes", "Tour"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The OPScalar Package", "Section"]], "Section",
  CellTags->"OPScalar"],

Cell[CellGroupData[{

Cell["Declare and undeclare operators:", "Subsection",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "This command loads the subpackage ",
  StyleBox["OPScalar ",
    FontWeight->"Bold"],
  StyleBox["provided you put all files of this package under the subdirectory \
OPLinearAlgebra of the directory AddOns\\Applications in the ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" system tree:",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(<< OPLinearAlgebra`OPScalar`\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "This gives the list of all functions and operations in the subpackage ",
  StyleBox["OPScalar",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?OPLinearAlgebra`OPScalar`*\)\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell["\<\
CanonicalOrder      CommutatorToDiamond PermitTimes
ClearAllOperators   Diamond             PowerToDiamond
ClearCommutator     DiamondToPower      SetAllOperators
ClearDiamond        OPExpand       SetAllOperatorsQ
ClearOperators      ListBasicOperators  SetCommutator
CollectPower        NCPower             SetDiamond
Commutator          OperatorQ           SetOperators
CommutatorQ\
\>", "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  CellTags->{"OPScalar", "declare"}]
}, Open  ]],

Cell[TextData[{
  " One of the most important operations this subpackage offers is the \
operation ",
  StyleBox["Diamond ",
    FontWeight->"Bold"],
  StyleBox["( \[Diamond]  in infix form). This is an analogue of the \
operation ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["NonCommutativeMultiply",
    FontWeight->"Bold"],
  StyleBox[" in the NCAlgebra package, but with significant extensions in \
capability. ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Diamond",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" is equivalent to the system operation ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Times",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[", if the operands are not declared operators.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(x\ \[Diamond]\ \((y + z)\)\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(Expand[\((u + v)\)\ \[Diamond]\ \((w + x)\)]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "One can declare variables of the type ",
  StyleBox["Operators",
    FontWeight->"Bold"],
  " in either one of two ways: one way is to declare everything except \
numbers as operators, using the command  ",
  StyleBox["SetAllOperators[]",
    FontWeight->"Bold"],
  " or ",
  StyleBox["On[SetAllOperators]",
    FontWeight->"Bold"],
  " (both are equivalent):"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(SetAllOperators[]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell["\<\
You can see immediately the effect of this command by examining the above \
examples again:\
\>", "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(x\ \[Diamond]\ \((y + z)\) // OPExpand\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "Notice that ",
  "OPExpand",
  StyleBox[" ",
    FontWeight->"Bold"],
  "is the analogue of ",
  StyleBox["Expand",
    FontWeight->"Bold"],
  " in the presence of operators. One can check whether a symbol or \
expression is an operator by using the Boolean function ",
  StyleBox["OperatorQ",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[x + y]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[5]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "One can also check whether the function ",
  StyleBox["SetAllOperators",
    FontWeight->"Bold"],
  " is now in effect:"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(SetAllOperatorsQ[]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "The other way of declaring operators is to declare a small set of basic \
operators using the function ",
  StyleBox["SetOperators",
    FontWeight->"Bold"],
  ". This function takes any sequence of atoms and/or lists as operand, \
provided there are no numerical elements in the sequence, and that every \
element of the lists (if any) must be an atom or an atom with a subscript. \
Once used,  every expressions involving the basic operators (namely, elements \
of the operand) are automatically treated as operators:"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(SetOperators[a, b, c, d]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[2  a + b]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[2  x + y]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell["\<\
Notice that the second way of declaring operators automatically override the \
first one without warning:\
\>", "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(SetAllOperatorsQ[]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "If ",
  StyleBox["a",
    FontWeight->"Bold"],
  " is declared as operator, any expressions taking ",
  StyleBox["a",
    FontWeight->"Bold"],
  " as Head are also regarded as operators."
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[a[x]]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "You can show the list of basic operators you have declared so far using \
the command ",
  StyleBox["ListBasicOperators",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    StyleBox[\(ListBasicOperators[]\),
      FontWeight->"Bold"]], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "The way of undeclaring operators need some more care. First of all, one \
can of cause clear selected names from the list of basic operators using ",
  StyleBox["ClearOperators[something]",
    FontWeight->"Bold"],
  StyleBox[". The structure of arguments is the same as that for ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["SetOperators",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[", and this command also override the effect of ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["SetAllOperators[]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" and/or ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["On[SetAllOperators]",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" without warning: ",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(ClearOperators[a, b]; ListBasicOperators[]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "Not unexpectedly, one can use the command ",
  StyleBox["Off[SetAllOperators]",
    FontWeight->"Bold"],
  " to switch off the ",
  StyleBox["SetAllOperators",
    FontWeight->"Bold"],
  " mode. The only thing to be noticed here is that ",
  StyleBox["On[SetAllOperators]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Off[SetAllOperators]",
    FontWeight->"Bold"],
  " do not change the list of user defined basic operators, thus the \
AllOperators mode can be switched on at certain stage of the calculation and \
switched off at a later time. However, there is also another command, i.e.  \
",
  StyleBox["ClearAllOperators[],",
    FontWeight->"Bold"],
  " which can be used to clear all basic operators at once (this also works \
when ",
  StyleBox["SetAllOperators",
    FontWeight->"Bold"],
  " is ",
  StyleBox["On",
    FontWeight->"Bold"],
  "):"
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(ClearAllOperators[]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[TextData[{
  "By default, nothing is declared as operators when the package loads, \
except the names of the special operator-oriented functions ",
  StyleBox["Commutator",
    FontWeight->"Bold"],
  " (",
  StyleBox["CM",
    FontWeight->"Bold"],
  " in output format) and ",
  StyleBox["Diamond,",
    FontWeight->"Bold"],
  " which are regarded as operators at any time."
}], "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[Commutator]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    \(OperatorQ[Diamond]\)], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell["\<\
Even all operators are cleared by the last command, matrices are still \
thought as operators:\
\>", "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", ":=", 
        RowBox[{"(", GridBox[{
              {"1", "2"},
              {"3", "4"}
              }], ")"}]}], ";", \(OperatorQ[A]\)}]], "Input",
  CellTags->{"OPScalar", "declare"}],

Cell["There is no way to treat matrices not as operators. ", "Text",
  CellTags->{"OPScalar", "declare"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Diamond multiplications and NCPower:", "Subsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[CellGroupData[{

Cell["Issues concerning Power function", "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The Diamond multiplication is in many faces resemble the ",
  StyleBox["NonCommutativeMultiply",
    FontWeight->"Bold"],
  " in NCAlgebra package, however it recognizes powers of the same symbol \
(actually we use the definition of ",
  StyleBox["NoncommutativeMultiply",
    FontWeight->"Bold"],
  " in NCAlgebra as the basic part of ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " definitions and added a lot more rules to it):"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(SetOperators[a, b, c, d]; 
    a\ \[Diamond]\ a\ \[Diamond]\ a\ \[Diamond]\ b\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "You may compare this with the result of the system function ",
  StyleBox["NonCommutativeMultiply",
    FontWeight->"Bold"],
  " (NCAlgebra packages' ",
  StyleBox["NonCommutativeMultiply",
    FontWeight->"Bold"],
  " gives the same result by default):"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(a ** a ** a ** b\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            TagBox[
              InterpretationBox[
                RowBox[{"a", "\[InvisibleSpace]", 
                  InterpretationBox[\(\[Null]\^3\),
                    Superscript[ 3],
                    Editable->False]}],
                SequenceForm[ a, 
                  Superscript[ 3]],
                Editable->False],
              (PrecedenceForm[ #, 590]&)],
            "TraditionalForm"], "\[InvisibleSpace]", "\<\"\"\>"}], 
        TraditionalForm]]],
  " appeared above has head ",
  StyleBox["Power",
    FontWeight->"Bold"],
  StyleBox[":",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(\((a\ \[Diamond]\ a\ \[Diamond]\ a\ \[Diamond]\ b)\)[\([1]\)] // 
      Head\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["However, one should be cautious with matrices:", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", ":=", 
        RowBox[{"(", GridBox[{
              {"1", "2"},
              {"3", "4"}
              }], ")"}]}], ";", 
      RowBox[{"B", ":=", 
        RowBox[{"(", GridBox[{
              {"5", "6"},
              {"7", "8"}
              }], ")"}]}], ";"}]], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(A\ \[Diamond]\ A\ \[Diamond]\ A\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "This does not evaluate to power of A itself, because the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Power has attribute \"Listable\", which makes it incorrect as \
power function of matrices:"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(A^2 - A . A\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The correct power function for matrices is also included in this package, \
which is called ",
  StyleBox["NCPower",
    FontWeight->"Bold"],
  ". However, no practical functionality is implemented within the subpackage \
",
  StyleBox["OPScalar",
    FontWeight->"Bold"],
  ". One should instead use the subpackage ",
  StyleBox["OPMatrix ",
    FontWeight->"Bold"],
  "to make practical use of this function."
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(NCPower[A, 3]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
Another aspect of the power functions involving operators that the users \
should be aware of is that, when operators appear in the exponents, usual \
simplification rules would not apply:\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Exp[a]\ \[Diamond]\ Exp[b]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["Compare this with", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Exp[f]\ \[Diamond]\ Exp[g]\)], "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Use of Diamond together with Times", "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
Notice that Diamond multiplications can be performed along with usual \
commutative multiplications. First let us keep a trace of basic operators:\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(ClearAllOperators[]; SetOperators[a, b, c, d]; 
    ListBasicOperators[]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["Then check the following:", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(b\ \[Diamond]\ \((a\ f)\)\ \[Diamond]\ \((g\ c)\)\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "Parentheses are needed here because ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " has higher precedence than ",
  StyleBox["Times",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Precedence[Diamond]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Precedence[Times]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
Any diamond multiplications over none operators are automatically changed \
into usual multiplications:\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(\((a + f)\)\ \[Diamond]\ \((b + g)\)\ \[Diamond]\ \((u + 
          v)\)\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "One can use the function ",
  "OPExpand",
  StyleBox[" ",
    FontWeight->"Bold"],
  "at any time to expand a ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " multiplication or a power expression of operators:"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OPExpand[\((a + f)\)\ \[Diamond]\ \((b + g)\)\ \[Diamond]\ \((u + 
            v)\)]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OPExpand[\((a + b)\)^4]\)], "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{

Cell["CollectPower modes", "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "One particular aspect of this software package is that it implements \
several mode switches. If this manual is to be read from top down, then the \
reader has already encountered one of the mode switches, i.e. the switches \
for the mode ",
  StyleBox["SetAllOperators",
    FontWeight->"Bold"],
  ". Now let us look at another mode switches, the ",
  StyleBox["CollectPower",
    FontWeight->"Bold"],
  " switches. This mode switches controls the behavior of Diamond in whether \
the powers of operators are collected or not. By default, every power is \
collected:"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OperatorQ /@ {f, a}\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(a\ \[Diamond]\ 
      a\ \[Diamond]\ \((a + b)\)\ \[Diamond]\ \((a + b)\)\ \[Diamond]\ 
      f\ \[Diamond]\ f\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
One can change this behavior by switching Off the mode CollectPower:\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Off[CollectPower]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["Now try this once again:", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(a\ \[Diamond]\ 
      a\ \[Diamond]\ \((a + b)\)\ \[Diamond]\ \((a + b)\)\ \[Diamond]\ 
      f\ \[Diamond]\ f\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
Only powers of commuting (none operator) objects are now collected! In this \
mode the OPExpand function also works differently:\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OPExpand[\((a + b)\)^4]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["Now we switch back to the normal mode:", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(On[CollectPower]\)], "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{

Cell["PermitTimes modes ", "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "Another switch of modes is concerned with the ",
  StyleBox["Times",
    FontWeight->"Bold"],
  " operation. This switch ",
  StyleBox["PermitTimes",
    FontWeight->"Bold"],
  " is implemented with partial success only. The reason for implementing \
such a mode switch is that, for operator objects, it is usually meaningless \
to write down commutative multiplications between them (i.e. ",
  StyleBox["Times",
    FontWeight->"Bold"],
  " expressions). Therefore, it is desired that whenever a Times expression \
for operators is entered, the output should be automatically changed into \
Diamond expressions while keeping the order of the operators entered. \
However, this is impossible because ",
  StyleBox["Times",
    FontWeight->"Bold"],
  " has attribute ",
  StyleBox["Orderless",
    FontWeight->"Bold"],
  ", which makes it automatically sort the order of the argument before \
applying any rule of definition. Therefore, the best we can do is that, when \
",
  StyleBox["PermitTimes",
    FontWeight->"Bold"],
  " is switched Off, the output of a ",
  StyleBox["Times",
    FontWeight->"Bold"],
  " expression for operators is a ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " expression with all operators appear in canonical order. By default, ",
  StyleBox["PermitTimes",
    FontWeight->"Bold"],
  " is switched ",
  StyleBox["On",
    FontWeight->"Bold"],
  " :"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(On[PermitTimes]; a\ b + a\ \[Diamond]\ a\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "This is the same expression when ",
  StyleBox["PermitTimes",
    FontWeight->"Bold"],
  " is ",
  StyleBox["Off",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Off[PermitTimes]; a\ b + a\ \[Diamond]\ a\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
The blue message texts are implemented in order to warn the users when \
another mode is entered.\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Assigning and unassigning values to Diamond expressions", \
"Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "One can assign values to Diamond product of two operators via the command \
",
  StyleBox["SetDiamond",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(SetDiamond[a, b, c]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The assigned values are not automatically used by the ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " function itself,"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(Diamond[a, b, c]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["but it is used when OPExpand is inferred:", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(% // OPExpand\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell["\<\
In future development of the package, this inconvenience may be overcome\
\>", "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The assigned values of ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " expressions can be removed by the command ClearDiamond. For example, the \
command"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(ClearDiamond[a, b]\)], "Input",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "removes the value of ",
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["\[Diamond]",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" b",
    FontSlant->"Italic"],
  " we just assigned:"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OPExpand[a\ \[Diamond]\ b\ \[Diamond]\ c]\)], "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{

Cell["OPExpand related issues", "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[TextData[{
  "The function ",
  "OPExpand",
  " has a number of particular effects. It not only expands every",
  StyleBox[" Diamond",
    FontWeight->"Bold"],
  " expressions, but also makes some simplifications for the expressions. One \
simplification it makes is the use of assigned values for Diamond \
expressions, which has been discussed earlier. Another simplification it \
makes is over negative power expressions. Look at the following example:"
}], "Text",
  CellTags->{"OPScalar", "diamond"}],

Cell[BoxData[
    \(OPExpand[\((c^\(-1\)\ \[Diamond]\ 
            b^\(-1\)\ \[Diamond]\ \ a^\(-2\))\)^\(-1\)]\)], "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Commutator and CommutatorQ", "Subsection",
  CellTags->{"OPScalar", "commutator"}],

Cell[CellGroupData[{

Cell["Commutator", "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],

Cell[TextData[{
  StyleBox["Commutator",
    FontWeight->"Bold"],
  " is another core function of this package. As its name suggests, this \
function evaluates the commutator of two operators. Unlike the inertial \
behavior of ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Commutator",
    FontWeight->"Bold"],
  " makes the evaluation automatically:"
}], "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(Commutator[\((a + b)\)\ \[Diamond]\ \((a - b)\), \((c + 
            d)\)\ \[Diamond]\ \((c - d)\)]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell["\<\
This function knows every rule which an ordinary commutator obeys, so\
\>", "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(Commutator[a, b] + Commutator[b, a]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell["and the Jacobi identity also holds:", "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(Commutator[a, Commutator[b, c]] + Commutator[b, Commutator[c, a]] + 
      Commutator[c, Commutator[a, b]]\)], "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]],

Cell[CellGroupData[{

Cell["CommutatorQ", "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],

Cell[TextData[{
  "This Boolean function is aimed at internal use only. It returns True if \
its arguments has a head ",
  StyleBox["Commutator ",
    FontWeight->"Bold"],
  StyleBox["(",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["CM ",
    FontWeight->"Bold"],
  StyleBox["actually, because that is the actual ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Head",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" of every commutator after evaluation)",
    FontVariations->{"CompatibilityType"->0}],
  ", False otherwise. The reason that this function is not shielded in the \
private sector of the package is that other subpackages may need to use it. \
Examples:"
}], "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(CommutatorQ[a]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(CommutatorQ[Commutator[a, b]]\)], "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Assigning value to Commutators", "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],

Cell[TextData[{
  "One can assign value to commutators by use of the function ",
  StyleBox["SetCommutator",
    FontWeight->"Bold"],
  ". This sets the value of \n",
  StyleBox["Commutator[a, b]",
    FontWeight->"Bold"],
  " to be equal to ",
  StyleBox["c",
    FontWeight->"Bold"],
  ":"
}], "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(SetCommutator[a, b, c]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell["This checks the result:", "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(Commutator[Commutator[a, b], c]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell["\<\
Assigned values of commutators can be unassigned using ClearCommutator:\
\>", "Text",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(ClearCommutator[a, b]\)], "Input",
  CellTags->{"OPScalar", "commutator"}],

Cell[BoxData[
    \(Commutator[Commutator[a, b], c]\)], "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Subtleties in Assigning values to Operators", "Subsection",
  CellTags->{"OPScalar", "assign"}],

Cell["\<\
There is some subtleties in assigning values to operators. Let us first \
prepare the environment:\
\>", "Text",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(ClearAllOperators[]; SetOperators[a, b, c, d]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell["\<\
First of all, assigning numerical values to operators automatically makes the \
operator no longer an operator.\
\>", "Text",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(a = 1; OperatorQ[a]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell["\<\
But if the value is cleared, the symbol recovers its role as operator \
automatically:\
\>", "Text",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(a =. ; OperatorQ[a]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell["\<\
The same is true if you make the assignment with set-delayed:\
\>", "Text",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(SetOperators[a]; a := 1; OperatorQ[a]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(a =. ; OperatorQ[a]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell["\<\
However, if the assigned value for operators is not numerical, then the \
assigned value is automatically changed into operator, and when this \
assignation is cleared, the assigned value is no longer an operator. During \
this process, the original operator always remain as operator:\
\>", "Text",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(b = f; OperatorQ[b]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(OperatorQ[f]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(b =. ; OperatorQ[b]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(OperatorQ[f]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(b := f; OperatorQ[b]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(OperatorQ[f]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(b =. ; OperatorQ[b]\)], "Input",
  CellTags->{"OPScalar", "assign"}],

Cell[BoxData[
    \(OperatorQ[f]\)], "Input",
  CellTags->{"OPScalar", "assign"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Conversions into Diamond Expressions", "Subsection",
  CellTags->{"OPScalar", "convert"}],

Cell[TextData[{
  "There are two functions which can be used to convert other expressions \
into Diamond expressions. One is the function ",
  StyleBox["CommutatorToDiamond",
    FontWeight->"Bold"],
  ", which is used to convert Commutators into Diamond expressions, and the \
other one is ",
  StyleBox["PowerToDiamond",
    FontWeight->"Bold"],
  ", which converts expressions in collect power mode into pure diamond \
mode:"
}], "Text",
  CellTags->{"OPScalar", "convert"}],

Cell[BoxData[
    \(CommutatorToDiamond[Commutator[a, b]]\)], "Input",
  CellTags->{"OPScalar", "convert"}],

Cell[BoxData[
    \(Off[CollectPower]; 
    PowerToDiamond[
      a^3\ \[Diamond]\ b^2 + c^3\ \[Diamond]\ d^\((\(-3\))\)]\)], "Input",
  CellTags->{"OPScalar", "convert"}],

Cell[TextData[{
  "Notice that, however, the function ",
  StyleBox["PowerToDiamond",
    FontWeight->"Bold"],
  " has no effect when ",
  StyleBox["CollectPower",
    FontWeight->"Bold"],
  " is ",
  StyleBox["On",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellTags->{"OPScalar", "convert"}],

Cell[BoxData[
    \(On[CollectPower]; 
    PowerToDiamond[
      a^3\ \[Diamond]\ b^2 + c^3\ \[Diamond]\ d^\((\(-3\))\)]\)], "Input",
  CellTags->{"OPScalar", "convert"}]
}, Closed]],

Cell[CellGroupData[{

Cell["CanonicalOrder", "Subsection",
  CellTags->{"OPScalar", "order"}],

Cell[TextData[{
  "There is a special function called ",
  StyleBox["CanonicalOrder",
    FontWeight->"Bold"],
  " in the subpackage OPScalar which is aimed at giving a canonical order to \
operator ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " products."
}], "Text",
  CellTags->{"OPScalar", "order"}],

Cell[BoxData[
    \(SetOperators[a, b, c, d]; 
    CanonicalOrder[d\ \[Diamond]\ c\ \[Diamond]\ b\ \[Diamond]\ a]\)], "Input",\

  CellTags->{"OPScalar", "order"}],

Cell["\<\
anything which is not in the canonical order are automatically converted into \
canonical one by use of the corresponding commutators. Consequently, this \
function can be used as the normal ordering function for Heisenberg \
operators, provided the Heisenberg algebra is defined such that the lowering \
operators precede the raising operators in the lexicographical order. For \
example, this defines a Heisenberg algebra:\
\>", "Text",
  CellTags->{"OPScalar", "order"}],

Cell[BoxData[
    \(SetCommutator[a[i_], a[j_], 
      If[i + j \[Equal] 0, \ \(-f[i]\), 0]]\)], "Input",
  CellTags->{"OPScalar", "order"}],

Cell["\<\
Then check the result of Canonical ordering of the Diamond product a[3] \
\[Diamond] a[2] \[Diamond] a[1] \[Diamond] a[-1] \[Diamond] a[-2] \[Diamond] \
a[-3]:\
\>", "Text",
  CellTags->{"OPScalar", "order"}],

Cell[BoxData[
    \(CanonicalOrder[
      a[3]\[Diamond]a[2]\[Diamond]a[1]\[Diamond]a[\(-1\)]\[Diamond]
        a[\(-2\)]\[Diamond]a[\(-3\)]]\)], "Input",
  CellTags->{"OPScalar", "order"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The OPMatrix Package", "Section"]], "Section",
  CellTags->"OPMatrix"],

Cell[CellGroupData[{

Cell["Enhanced Functionalists for Diamond", "Subsection",
  CellTags->{"OPMatrix", "enhance"}],

Cell["\<\
In the subpackage, the function Diamond is greatly enhanced so that it can \
also recognize matrix operands:\
\>", "Text",
  CellTags->{"OPMatrix", "enhance"}],

Cell[BoxData[
    \(<< OPLinearAlgebra`OPMatrix`\)], "Input",
  GeneratedCell->True,
  CellTags->{"OPMatrix", "enhance"}],

Cell[BoxData[
    RowBox[{
      RowBox[{"A", ":=", 
        RowBox[{"(", GridBox[{
              {\(a[1]\), \(a[2]\)},
              {\(a[3]\), \(a[4]\)}
              }], ")"}]}], ";", 
      RowBox[{"B", ":=", 
        RowBox[{"(", GridBox[{
              {\(b[1]\), \(b[2]\)},
              {\(b[3]\), \(b[4]\)}
              }], ")"}]}], ";"}]], "Input",
  CellTags->{"OPMatrix", "enhance"}],

Cell["Now check this:", "Text",
  CellTags->{"OPMatrix", "enhance"}],

Cell[BoxData[
    \(c\ \[Diamond]\ A\)], "Input",
  CellTags->{"OPMatrix", "enhance"}],

Cell[BoxData[
    \(A\ \[Diamond]\ B\)], "Input",
  CellTags->{"OPMatrix", "enhance"}],

Cell[TextData[{
  "We see that now ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " plays both the roles of  multiplication by a scalar and the matrix \
multiplication in noncommutative basis. And the additional functionality of \
",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " can be used in mixture with the original:"
}], "Text",
  CellTags->{"OPMatrix", "enhance"}],

Cell[BoxData[
    \(A\ \[Diamond]\ d\ \[Diamond]\ B\)], "Input",
  CellTags->{"OPMatrix", "enhance"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Direct Products and Direct Sums of Matrices", "Subsection",
  CellTags->{"OPMatrix", "dprod"}],

Cell[TextData[{
  "These tasks are pursued by the functions ",
  StyleBox["CircleTimes",
    FontWeight->"Bold"],
  " (also called ",
  StyleBox["DProd",
    FontWeight->"Bold"],
  ") and ",
  StyleBox["CirclePlus",
    FontWeight->"Bold"],
  ". The infix forms are respectively ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CircleTimes]\ \ and\)\ \ \[CirclePlus] . \)]],
  " These two functions are among the ones which are not necessarily to be \
based on noncommutative basis. They  just were missing from the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " built-in and add-on functions and are important in advanced matrix \
manipulations, especially in theoretical physics contexts. Of cause, we \
introduce these functions with capabilities of noncommutative objects: "
}], "Text",
  CellTags->{"OPMatrix", "dprod"}],

Cell[BoxData[
    \(A\[CircleTimes]B\)], "Input",
  CellTags->{"OPMatrix", "dprod"}],

Cell[BoxData[
    \(A\[CirclePlus]B\)], "Input",
  CellTags->{"OPMatrix", "dprod"}]
}, Closed]],

Cell[CellGroupData[{

Cell["CircleCommutator", "Subsection",
  CellTags->{"OPMatrix", "circlecom"}],

Cell["\<\
CircleCommutator is a combination of Commutator with CircleTimes.\
\>", "Text",
  CellTags->{"OPMatrix", "circlecom"}],

Cell[BoxData[
    \(CircleCommutator[A, B]\)], "Input",
  CellTags->{"OPMatrix", "circlecom"}]
}, Closed]],

Cell[CellGroupData[{

Cell["ComplementMatrix", "Subsection",
  CellTags->{"OPMatrix", "complement"}],

Cell["\<\
This is a function aimed making matrices out of existing one by deleting \
specified row and column. For example,\
\>", "Text",
  CellTags->{"OPMatrix", "complement"}],

Cell[BoxData[
    \(T := Table[a[i, j], {i, 1, 4}, {j, 1, 4}]; \(ComplementMatrix[2, 3]\)[
      T]\)], "Input",
  CellTags->{"OPMatrix", "complement"}]
}, Closed]],

Cell[CellGroupData[{

Cell["DiagonalPart", "Subsection",
  CellTags->{"OPMatrix", "diagonal"}],

Cell[TextData[{
  "As its name suggests, this function takes out the diagonal elements of a \
matrix and form a new matrix. Remember that ",
  StyleBox["T",
    FontWeight->"Bold"],
  " has been defined in the context under ",
  StyleBox["ComplementMatrix",
    FontWeight->"Bold"],
  ". This takes out its diagonal elements:"
}], "Text",
  CellTags->{"OPMatrix", "diagonal"}],

Cell[BoxData[
    \(DiagonalPart[T]\)], "Input",
  CellTags->{"OPMatrix", "diagonal"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Gauss Decomposition of Matrices", "Subsection",
  CellTags->{"OPMatrix", "gauss"}],

Cell[TextData[{
  "There are 4 functions of this class: ",
  StyleBox["GaussDecompose",
    FontWeight->"Bold"],
  " returns the list of three matrices, namely the lower diagonal, diagonal \
and upper diagonal parts of a given matrix. Each one of the three parts can \
be obtained individually by the use of functions ",
  StyleBox["GaussL",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GaussD",
    FontWeight->"Bold"],
  " and ",
  StyleBox["GaussU",
    FontWeight->"Bold"],
  ": "
}], "Text",
  CellTags->{"OPMatrix", "gauss"}],

Cell[BoxData[
    \(A := {{a[1], a[2]}, {a[3], a[4]}}; B := A /. a \[Rule] b;\)], "Input",
  CellTags->{"OPMatrix", "gauss"}],

Cell[BoxData[
    \(GaussL[A]\)], "Input",
  CellTags->{"OPMatrix", "gauss"}],

Cell[BoxData[
    \(GaussU[A]\)], "Input",
  CellTags->{"OPMatrix", "gauss"}],

Cell[BoxData[
    \(GaussD[A]\)], "Input",
  CellTags->{"OPMatrix", "gauss"}],

Cell[BoxData[
    \(\(GaussDecompose[B]\)[\([1]\)]\)], "Input",
  CellTags->{"OPMatrix", "gauss"}],

Cell[TextData[{
  "In principle, ",
  StyleBox["GaussL[x]",
    FontWeight->"Bold"],
  " is equivalent to ",
  StyleBox["GaussDecompose[x][[1]]",
    FontWeight->"Bold"],
  StyleBox[", but the former is faster than the latter because the use of the \
former does not require the calculation of the useless matrices ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["GaussD",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" and ",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["GaussU",
    FontWeight->"Bold",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[" if they are not required.",
    FontVariations->{"CompatibilityType"->0}]
}], "Text",
  CellTags->{"OPMatrix", "gauss"}]
}, Closed]],

Cell[CellGroupData[{

Cell["inv and ncinv", "Subsection",
  CellTags->{"OPMatrix", "inv"}],

Cell[TextData[{
  "These two functions are both intended for the evaluation of inverses of \
matrices with noncommutative entries, however, ",
  StyleBox["ncinv",
    FontWeight->"Bold"],
  " is a very naive and hence slow implementation, and is considered \
obsoleted. Use ",
  StyleBox["inv",
    FontWeight->"Bold"],
  " whenever possible."
}], "Text",
  CellTags->{"OPMatrix", "inv"}],

Cell[BoxData[
    \(inv[A]\)], "Input",
  CellTags->{"OPMatrix", "inv"}],

Cell["\<\
Notice that the output of inv can be very complicated. No simplification rule \
has been implemented yet - and this is partly due to the requirement of high \
speed: inv can evaluate the inverse of symbolic matrices even faster than the \
system Inverse command. In future releases certain simplification rules might \
be implemented.\
\>", "Text",
  CellTags->{"OPMatrix", "inv"}],

Cell[TextData[{
  "A last comment about the inv function: the negative integer powers (",
  StyleBox["NCPower",
    FontWeight->"Bold"],
  ") of any Gauss type matrices are automatically turned into positive powers \
of the inverse of the same matrix. For instance,"
}], "Text",
  CellTags->{"OPMatrix", "inv"}],

Cell[BoxData[
    \(K := {{1, a, c}, {0, 1, b}, {0, 0, 1}}\)], "Input",
  CellTags->{"OPMatrix", "inv"}],

Cell[BoxData[
    \(NCPower[K, \(-2\)]\)], "Input",
  CellTags->{"OPMatrix", "inv"}],

Cell[BoxData[
    \(NCPower[K, \(-2\)]\)], "Input",
  CellTags->{"OPMatrix", "inv"}],

Cell[BoxData[
    \(PowerToDiamond[%]\)], "Input",
  CellTags->{"OPMatrix", "inv"}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Left and Right Determinants, Reversion of Diamond Expressions\
\>", "Subsection",
  CellTags->{"OPMatrix", "det"}],

Cell[TextData[{
  "For matrices with operator entries, there is no unique way of defining the \
determinant. This package implemented two different determinant functions \
called ",
  StyleBox["LeftDet",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RightDet",
    FontWeight->"Bold"],
  " respectively,"
}], "Text",
  CellTags->{"OPMatrix", "det"}],

Cell[BoxData[
    \(LeftDet[A]\)], "Input",
  CellTags->{"OPMatrix", "det"}],

Cell[BoxData[
    \(RightDet[A]\)], "Input",
  CellTags->{"OPMatrix", "det"}],

Cell[TextData[{
  "It might be sometimes useful to reverse the order of a ",
  StyleBox["Diamond",
    FontWeight->"Bold"],
  " expression, ",
  StyleBox["RevDiamond",
    FontWeight->"Bold"],
  " provides such a functionality:"
}], "Text",
  CellTags->{"OPMatrix", "det"}],

Cell[BoxData[
    \(RevDiamond[LeftDet[A]] - RightDet[A]\)], "Input",
  CellTags->{"OPMatrix", "det"}],

Cell[TextData[{
  "Notice however, that ",
  StyleBox["LeftDe",
    FontWeight->"Bold"],
  "t and ",
  StyleBox["RightDet",
    FontWeight->"Bold"],
  " are defined internally differently, without using the function ",
  StyleBox["RevDiamond",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellTags->{"OPMatrix", "det"}]
}, Closed]],

Cell[CellGroupData[{

Cell["LeftMinor and RightMinor", "Subsection",
  CellTags->{"OPMatrix", "minor"}],

Cell["\<\
These two functions gives the algebraic co-minors of a given matrix with \
respect to a specified element. They are basically the Left and Right \
determinants of some ComplementMatrix of the given matrix with an extra \
signature.\
\>", "Text",
  CellTags->{"OPMatrix", "minor"}],

Cell[BoxData[
    \(T := Table[a[i, j], {i, 1, 4}, {j, 1, 4}]; \(LeftMinor[2, 2]\)[T] // 
      OPExpand\)], "Input",
  CellTags->{"OPMatrix", "minor"}],

Cell[BoxData[
    \(\(RightMinor[2, 2]\)[T] // OPExpand\)], "Input",
  CellTags->{"OPMatrix", "minor"}]
}, Closed]],

Cell[CellGroupData[{

Cell["LUFacOPMatrix", "Subsection",
  CellTags->{"OPMatrix", "lufac"}],

Cell[TextData[{
  "This function is an analogue of the system add-on function ",
  StyleBox["`LinearAlgebra`GaussianElimination`LUFactor ",
    FontWeight->"Bold"],
  "except for the different output format."
}], "Text",
  CellTags->{"OPMatrix", "lufac"}],

Cell[BoxData[
    \(LUFacOPMatrix[T]\)], "Input",
  CellTags->{"OPMatrix", "lufac"}]
}, Closed]],

Cell[CellGroupData[{

Cell["OPLinearSolve", "Subsection",
  CellTags->{"OPMatrix", "oplsol"}],

Cell["\<\
This function is the basic building block of the OPSolve function to be \
implemented in another subpackage, OPSolve.m, of this software package. \
OPLinearSolve[List, Mat] solves the linear equation List == X . Mat; 
OPLinearSolve[Mat, List] solves the linear equation Mat . X == List.\
\>", "Text",
  CellTags->{"OPMatrix", "oplsol"}],

Cell[BoxData[
    \(Coef := UpperDiagonalMatrix[a, 3]\)], "Input",
  CellTags->{"OPMatrix", "oplsol"}],

Cell[BoxData[
    \(OPLinearSolve[Coef, {b[1], b[2], b[3]}]\)], "Input",
  CellTags->{"OPMatrix", "oplsol"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["The Poisson Bracket Package", "Section"]], "Section",
  CellTags->"Poisson"],

Cell[CellGroupData[{

Cell["The function Poisson ", "Subsection",
  CellTags->{"Poisson", "poisson"}],

Cell["\<\
The function Poisson is an analogue of Commutator but for several factors: a \
Poisson bracket is a classical objects, and so it does not appear in mixture \
with Diamond expressions; Poisson brackets cannot be converted into Diamond \
products; and further, Poisson brackets knows some more rules of evaluation. \
For example,\
\>", "Text",
  CellTags->{"Poisson", "poisson"}],

Cell[BoxData[
    \(<< OPLinearAlgebra`Poisson`\)], "Input",
  GeneratedCell->True,
  CellTags->{"Poisson", "poisson"}],

Cell[BoxData[
    \(SetOperators[a, b, c, d, \ c\_1]\)], "Input",
  CellTags->{"Poisson", "poisson"}],

Cell[BoxData[
    \(Poisson[Sin[a\ b], c/\((d - a)\)] // Expand\)], "Input",
  CellTags->{"Poisson", "poisson"}],

Cell["\<\
The point is that the function Sin is differentiated over to get the final \
result. Notice that the output of Poisson has a different head:\
\>", "Text",
  CellTags->{"Poisson", "poisson"}],

Cell[BoxData[
    \(\(-Poisson[a[1], b]\) // Head\)], "Input",
  CellTags->{"Poisson", "poisson"}]
}, Closed]],

Cell[CellGroupData[{

Cell["SetPoisson", "Subsection",
  CellTags->{"Poisson", "setpoisson"}],

Cell["This function assigns values to Poisson brackets.", "Text",
  CellTags->{"Poisson", "setpoisson"}],

Cell[BoxData[
    \(SetPoisson[a, b, 1]; Poisson[a, b]\)], "Input",
  CellTags->{"Poisson", "setpoisson"}]
}, Closed]],

Cell[CellGroupData[{

Cell["CirclePoisson", "Subsection",
  CellTags->{"Poisson", "circlepoisson"}],

Cell["\<\
This function is an analogue of the function CircleCommutator. Basically this \
is a combination of Poisson bracket with matrix direct product.\
\>", "Text",
  CellTags->{"Poisson", "circlepoisson"}],

Cell[BoxData[
    RowBox[{\(SetOperators[c, d]\), ";", 
      RowBox[{"L1", ":=", 
        RowBox[{"(", GridBox[{
              {\(c[1]\), \(c[2]\)},
              {\(c[3]\), \(c[4]\)}
              }], ")"}]}], ";", 
      RowBox[{"L2", ":=", 
        RowBox[{"(", GridBox[{
              {\(d[1]\), \(d[2]\)},
              {\(d[3]\), \(d[4]\)}
              }], ")"}]}], ";", \(CirclePoisson[L1, L2]\)}]], "Input",
  CellTags->"circlepoisson"]
}, Closed]],

Cell[CellGroupData[{

Cell["Other functions in the package Poisson", "Subsection",
  CellTags->{"Poisson", "other"}],

Cell["\<\
There are a number of other functions in the package Poisson, but all of them \
are of experimental nature only at present, hence no further documentations \
on them.\
\>", "Text",
  CellTags->{"Poisson", "other"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["The OPSolve Package", "Section",
  CellTags->"OPSolve"],

Cell[TextData[{
  "There are only two functions in this package: the ",
  StyleBox["OPLinearEqnToMatrix",
    FontWeight->"Bold"],
  " function and the ",
  StyleBox["OPSolve",
    FontWeight->"Bold"],
  " function.  The former converts a system of operator valued linear \
equations into the set of a coefficient matrix and a list of constants, and \
the latter makes a call to the first and the function OPLinearSolve to solve \
the system of linear equations."
}], "Text",
  CellTags->"OPSolve"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 991}, {0, 695}},
WindowToolbars->"EditBar",
WindowSize->{767, 517},
WindowMargins->{{23, Automatic}, {Automatic, 14}},
IndexCreationOptions->{"Format"->"Hyperlinks"},
ShowCellTags->True,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "copynotice"->{
    Cell[1739, 51, 638, 18, 346, "Title",
      CellTags->"copynotice"]},
  "Disclaimer"->{
    Cell[2402, 73, 55, 1, 67, "Section",
      CellTags->"Disclaimer"],
    Cell[2460, 76, 857, 15, 199, "Text",
      CellTags->"Disclaimer"],
    Cell[3320, 93, 182, 5, 47, "Text",
      CellTags->"Disclaimer"]},
  "Introduction"->{
    Cell[3539, 103, 81, 1, 47, "Section",
      CellTags->"Introduction"],
    Cell[3623, 106, 2381, 48, 389, "Text",
      CellTags->"Introduction"]},
  "Tour"->{
    Cell[6041, 159, 69, 1, 47, "Section",
      CellTags->"Tour"],
    Cell[6135, 164, 77, 1, 61, "Subsection",
      CellTags->{"Tour", "install"}],
    Cell[6215, 167, 2189, 43, 370, "Text",
      CellTags->{"install", "Tour"}],
    Cell[8441, 215, 71, 1, 45, "Subsection",
      CellTags->{"Tour", "load"}],
    Cell[8515, 218, 215, 5, 66, "Text",
      CellTags->{"load", "Tour"}],
    Cell[8733, 225, 82, 2, 44, "Input",
      CellTags->{"load", "Tour"}],
    Cell[8818, 229, 709, 13, 180, "Text",
      CellTags->{"load", "Tour"}],
    Cell[9564, 247, 72, 1, 45, "Subsection",
      CellTags->{"Tour", "reload"}],
    Cell[9639, 250, 982, 17, 142, "Text",
      CellTags->{"Tour", "reload"}],
    Cell[10658, 272, 68, 1, 45, "Subsection",
      CellTags->{"Tour", "palettes"}],
    Cell[10729, 275, 412, 9, 85, "Text",
      CellTags->{"palettes", "Tour"}]},
  "install"->{
    Cell[6135, 164, 77, 1, 61, "Subsection",
      CellTags->{"Tour", "install"}],
    Cell[6215, 167, 2189, 43, 370, "Text",
      CellTags->{"install", "Tour"}]},
  "load"->{
    Cell[8441, 215, 71, 1, 45, "Subsection",
      CellTags->{"Tour", "load"}],
    Cell[8515, 218, 215, 5, 66, "Text",
      CellTags->{"load", "Tour"}],
    Cell[8733, 225, 82, 2, 44, "Input",
      CellTags->{"load", "Tour"}],
    Cell[8818, 229, 709, 13, 180, "Text",
      CellTags->{"load", "Tour"}]},
  "reload"->{
    Cell[9564, 247, 72, 1, 45, "Subsection",
      CellTags->{"Tour", "reload"}],
    Cell[9639, 250, 982, 17, 142, "Text",
      CellTags->{"Tour", "reload"}]},
  "palettes"->{
    Cell[10658, 272, 68, 1, 45, "Subsection",
      CellTags->{"Tour", "palettes"}],
    Cell[10729, 275, 412, 9, 85, "Text",
      CellTags->{"palettes", "Tour"}]},
  "OPScalar"->{
    Cell[11190, 290, 94, 1, 47, "Section",
      CellTags->"OPScalar"],
    Cell[11309, 295, 91, 1, 61, "Subsection",
      CellTags->{"OPScalar", "declare"}],
    Cell[11403, 298, 516, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[11922, 313, 98, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[12023, 317, 194, 6, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[12242, 327, 101, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[12346, 331, 498, 12, 158, "Print",
      CellTags->{"OPScalar", "declare"}],
    Cell[12859, 346, 920, 24, 85, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[13782, 372, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[13881, 376, 114, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[13998, 380, 428, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[14429, 395, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[14519, 399, 152, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[14674, 405, 108, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[14785, 409, 392, 14, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[15180, 425, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15269, 429, 82, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15354, 433, 188, 6, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[15545, 441, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15636, 445, 588, 11, 104, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[16227, 458, 94, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16324, 462, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16416, 466, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16508, 470, 166, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[16677, 476, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16768, 480, 255, 9, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[17026, 491, 85, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[17114, 495, 220, 7, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[17337, 504, 126, 3, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[17466, 509, 961, 23, 85, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[18430, 534, 112, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[18545, 538, 928, 28, 104, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[19476, 568, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[19568, 572, 428, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[19999, 587, 91, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20093, 591, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20184, 595, 155, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[20342, 601, 233, 7, 55, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20578, 610, 105, 1, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[20720, 616, 95, 1, 45, "Subsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[20840, 621, 94, 1, 57, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[20937, 624, 505, 13, 85, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21445, 639, 147, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21595, 644, 322, 9, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21920, 655, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22009, 659, 766, 24, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22778, 685, 146, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22927, 690, 99, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23029, 693, 356, 12, 55, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23388, 707, 101, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23492, 711, 285, 7, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23780, 720, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23864, 724, 479, 14, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24346, 740, 83, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24432, 744, 249, 5, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24684, 751, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24783, 755, 70, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24856, 758, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24989, 765, 96, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25088, 768, 207, 4, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25298, 774, 142, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25443, 779, 78, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25524, 782, 119, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25646, 786, 238, 9, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25887, 797, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25979, 801, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26069, 805, 164, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26236, 811, 142, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26381, 816, 283, 10, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26667, 828, 154, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26824, 833, 93, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26954, 840, 80, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27037, 843, 636, 14, 104, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27676, 859, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27768, 863, 180, 4, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27951, 869, 129, 3, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28083, 874, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28173, 878, 77, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28253, 881, 180, 4, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28436, 887, 189, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28628, 893, 93, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28724, 897, 91, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28818, 900, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28941, 907, 80, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[29024, 910, 1456, 40, 161, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30483, 952, 110, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30596, 956, 213, 9, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30812, 967, 111, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30926, 971, 158, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31121, 980, 119, 2, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31243, 984, 202, 7, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31448, 993, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31540, 997, 193, 6, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31736, 1005, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31825, 1009, 94, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31922, 1012, 83, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32008, 1016, 133, 3, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32144, 1021, 228, 7, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32375, 1030, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32466, 1034, 313, 12, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32782, 1048, 111, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32930, 1055, 85, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[33018, 1058, 510, 11, 85, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[33531, 1071, 160, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[33740, 1080, 88, 1, 45, "Subsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[33853, 1085, 75, 1, 57, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[33931, 1088, 427, 13, 66, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34361, 1103, 172, 3, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34536, 1108, 133, 3, 44, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34672, 1113, 108, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34783, 1117, 91, 1, 44, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34877, 1120, 179, 3, 64, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35093, 1128, 76, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35172, 1131, 784, 20, 85, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35959, 1153, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36049, 1157, 102, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36188, 1164, 95, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36286, 1167, 343, 12, 66, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36632, 1181, 95, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36730, 1185, 79, 1, 47, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36812, 1188, 104, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36919, 1192, 135, 3, 47, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[37057, 1197, 94, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[37154, 1201, 104, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[37307, 1209, 106, 1, 45, "Subsection",
      CellTags->{"OPScalar", "assign"}],
    Cell[37416, 1212, 158, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[37577, 1218, 114, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[37694, 1222, 171, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[37868, 1228, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[37959, 1232, 146, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38108, 1238, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38199, 1242, 121, 3, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38323, 1247, 106, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38432, 1251, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38523, 1255, 345, 6, 85, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38871, 1263, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38962, 1267, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39046, 1271, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39137, 1275, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39221, 1279, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39313, 1283, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39397, 1287, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39488, 1291, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39606, 1298, 95, 1, 45, "Subsection",
      CellTags->{"OPScalar", "convert"}],
    Cell[39704, 1301, 477, 12, 85, "Text",
      CellTags->{"OPScalar", "convert"}],
    Cell[40184, 1315, 107, 2, 44, "Input",
      CellTags->{"OPScalar", "convert"}],
    Cell[40294, 1319, 171, 4, 44, "Input",
      CellTags->{"OPScalar", "convert"}],
    Cell[40468, 1325, 295, 12, 33, "Text",
      CellTags->{"OPScalar", "convert"}],
    Cell[40766, 1339, 170, 4, 30, "Input",
      CellTags->{"OPScalar", "convert"}],
    Cell[40973, 1348, 71, 1, 45, "Subsection",
      CellTags->{"OPScalar", "order"}],
    Cell[41047, 1351, 310, 10, 66, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[41360, 1363, 163, 4, 44, "Input",
      CellTags->{"OPScalar", "order"}],
    Cell[41526, 1369, 483, 8, 85, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[42012, 1379, 140, 3, 44, "Input",
      CellTags->{"OPScalar", "order"}],
    Cell[42155, 1384, 218, 5, 47, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[42376, 1391, 189, 4, 44, "Input",
      CellTags->{"OPScalar", "order"}]},
  "declare"->{
    Cell[11309, 295, 91, 1, 61, "Subsection",
      CellTags->{"OPScalar", "declare"}],
    Cell[11403, 298, 516, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[11922, 313, 98, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[12023, 317, 194, 6, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[12242, 327, 101, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[12346, 331, 498, 12, 158, "Print",
      CellTags->{"OPScalar", "declare"}],
    Cell[12859, 346, 920, 24, 85, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[13782, 372, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[13881, 376, 114, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[13998, 380, 428, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[14429, 395, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[14519, 399, 152, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[14674, 405, 108, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[14785, 409, 392, 14, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[15180, 425, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15269, 429, 82, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15354, 433, 188, 6, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[15545, 441, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[15636, 445, 588, 11, 104, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[16227, 458, 94, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16324, 462, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16416, 466, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16508, 470, 166, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[16677, 476, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[16768, 480, 255, 9, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[17026, 491, 85, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[17114, 495, 220, 7, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[17337, 504, 126, 3, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[17466, 509, 961, 23, 85, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[18430, 534, 112, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[18545, 538, 928, 28, 104, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[19476, 568, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[19568, 572, 428, 13, 66, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[19999, 587, 91, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20093, 591, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20184, 595, 155, 4, 47, "Text",
      CellTags->{"OPScalar", "declare"}],
    Cell[20342, 601, 233, 7, 55, "Input",
      CellTags->{"OPScalar", "declare"}],
    Cell[20578, 610, 105, 1, 47, "Text",
      CellTags->{"OPScalar", "declare"}]},
  "diamond"->{
    Cell[20720, 616, 95, 1, 45, "Subsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[20840, 621, 94, 1, 57, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[20937, 624, 505, 13, 85, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21445, 639, 147, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21595, 644, 322, 9, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[21920, 655, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22009, 659, 766, 24, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22778, 685, 146, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[22927, 690, 99, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23029, 693, 356, 12, 55, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23388, 707, 101, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23492, 711, 285, 7, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23780, 720, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[23864, 724, 479, 14, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24346, 740, 83, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24432, 744, 249, 5, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24684, 751, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24783, 755, 70, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24856, 758, 96, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[24989, 765, 96, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25088, 768, 207, 4, 66, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25298, 774, 142, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25443, 779, 78, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25524, 782, 119, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25646, 786, 238, 9, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25887, 797, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[25979, 801, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26069, 805, 164, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26236, 811, 142, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26381, 816, 283, 10, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26667, 828, 154, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26824, 833, 93, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[26954, 840, 80, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27037, 843, 636, 14, 104, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27676, 859, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27768, 863, 180, 4, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[27951, 869, 129, 3, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28083, 874, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28173, 878, 77, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28253, 881, 180, 4, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28436, 887, 189, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28628, 893, 93, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28724, 897, 91, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28818, 900, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[28941, 907, 80, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[29024, 910, 1456, 40, 161, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30483, 952, 110, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30596, 956, 213, 9, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30812, 967, 111, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[30926, 971, 158, 4, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31121, 980, 119, 2, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31243, 984, 202, 7, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31448, 993, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31540, 997, 193, 6, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31736, 1005, 86, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31825, 1009, 94, 1, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[31922, 1012, 83, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32008, 1016, 133, 3, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32144, 1021, 228, 7, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32375, 1030, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32466, 1034, 313, 12, 47, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32782, 1048, 111, 2, 44, "Input",
      CellTags->{"OPScalar", "diamond"}],
    Cell[32930, 1055, 85, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "diamond"}],
    Cell[33018, 1058, 510, 11, 85, "Text",
      CellTags->{"OPScalar", "diamond"}],
    Cell[33531, 1071, 160, 3, 44, "Input",
      CellTags->{"OPScalar", "diamond"}]},
  "commutator"->{
    Cell[33740, 1080, 88, 1, 45, "Subsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[33853, 1085, 75, 1, 57, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[33931, 1088, 427, 13, 66, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34361, 1103, 172, 3, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34536, 1108, 133, 3, 44, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34672, 1113, 108, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34783, 1117, 91, 1, 44, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[34877, 1120, 179, 3, 64, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35093, 1128, 76, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35172, 1131, 784, 20, 85, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[35959, 1153, 87, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36049, 1157, 102, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36188, 1164, 95, 1, 43, "Subsubsection",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36286, 1167, 343, 12, 66, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36632, 1181, 95, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36730, 1185, 79, 1, 47, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36812, 1188, 104, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[36919, 1192, 135, 3, 47, "Text",
      CellTags->{"OPScalar", "commutator"}],
    Cell[37057, 1197, 94, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}],
    Cell[37154, 1201, 104, 2, 44, "Input",
      CellTags->{"OPScalar", "commutator"}]},
  "assign"->{
    Cell[37307, 1209, 106, 1, 45, "Subsection",
      CellTags->{"OPScalar", "assign"}],
    Cell[37416, 1212, 158, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[37577, 1218, 114, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[37694, 1222, 171, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[37868, 1228, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[37959, 1232, 146, 4, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38108, 1238, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38199, 1242, 121, 3, 47, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38323, 1247, 106, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38432, 1251, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38523, 1255, 345, 6, 85, "Text",
      CellTags->{"OPScalar", "assign"}],
    Cell[38871, 1263, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[38962, 1267, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39046, 1271, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39137, 1275, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39221, 1279, 89, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39313, 1283, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39397, 1287, 88, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}],
    Cell[39488, 1291, 81, 2, 44, "Input",
      CellTags->{"OPScalar", "assign"}]},
  "convert"->{
    Cell[39606, 1298, 95, 1, 45, "Subsection",
      CellTags->{"OPScalar", "convert"}],
    Cell[39704, 1301, 477, 12, 85, "Text",
      CellTags->{"OPScalar", "convert"}],
    Cell[40184, 1315, 107, 2, 44, "Input",
      CellTags->{"OPScalar", "convert"}],
    Cell[40294, 1319, 171, 4, 44, "Input",
      CellTags->{"OPScalar", "convert"}],
    Cell[40468, 1325, 295, 12, 33, "Text",
      CellTags->{"OPScalar", "convert"}],
    Cell[40766, 1339, 170, 4, 30, "Input",
      CellTags->{"OPScalar", "convert"}]},
  "order"->{
    Cell[40973, 1348, 71, 1, 45, "Subsection",
      CellTags->{"OPScalar", "order"}],
    Cell[41047, 1351, 310, 10, 66, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[41360, 1363, 163, 4, 44, "Input",
      CellTags->{"OPScalar", "order"}],
    Cell[41526, 1369, 483, 8, 85, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[42012, 1379, 140, 3, 44, "Input",
      CellTags->{"OPScalar", "order"}],
    Cell[42155, 1384, 218, 5, 47, "Text",
      CellTags->{"OPScalar", "order"}],
    Cell[42376, 1391, 189, 4, 44, "Input",
      CellTags->{"OPScalar", "order"}]},
  "OPMatrix"->{
    Cell[42614, 1401, 94, 1, 47, "Section",
      CellTags->"OPMatrix"],
    Cell[42733, 1406, 94, 1, 61, "Subsection",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[42830, 1409, 169, 4, 47, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43002, 1415, 121, 3, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43126, 1420, 396, 12, 55, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43525, 1434, 68, 1, 47, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43596, 1437, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43685, 1441, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43774, 1445, 381, 11, 66, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[44158, 1458, 101, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[44296, 1465, 100, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[44399, 1468, 845, 21, 104, "Text",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[45247, 1491, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[45334, 1495, 83, 2, 44, "Input",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[45454, 1502, 77, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "circlecom"}],
    Cell[45534, 1505, 128, 3, 47, "Text",
      CellTags->{"OPMatrix", "circlecom"}],
    Cell[45665, 1510, 94, 2, 44, "Input",
      CellTags->{"OPMatrix", "circlecom"}],
    Cell[45796, 1517, 78, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "complement"}],
    Cell[45877, 1520, 177, 4, 47, "Text",
      CellTags->{"OPMatrix", "complement"}],
    Cell[46057, 1526, 152, 3, 44, "Input",
      CellTags->{"OPMatrix", "complement"}],
    Cell[46246, 1534, 72, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "diagonal"}],
    Cell[46321, 1537, 376, 10, 66, "Text",
      CellTags->{"OPMatrix", "diagonal"}],
    Cell[46700, 1549, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "diagonal"}],
    Cell[46823, 1556, 88, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[46914, 1559, 531, 17, 85, "Text",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47448, 1578, 125, 2, 30, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47576, 1582, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47656, 1586, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47736, 1590, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47816, 1594, 98, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47917, 1598, 749, 21, 66, "Text",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[48703, 1624, 68, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "inv"}],
    Cell[48774, 1627, 388, 11, 66, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49165, 1640, 72, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49240, 1644, 391, 7, 85, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49634, 1653, 311, 7, 66, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49948, 1662, 104, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50055, 1666, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50142, 1670, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50229, 1674, 83, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50349, 1681, 124, 3, 45, "Subsection",
      CellTags->{"OPMatrix", "det"}],
    Cell[50476, 1686, 351, 11, 66, "Text",
      CellTags->{"OPMatrix", "det"}],
    Cell[50830, 1699, 76, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[50909, 1703, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[50989, 1707, 273, 9, 47, "Text",
      CellTags->{"OPMatrix", "det"}],
    Cell[51265, 1718, 102, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[51370, 1722, 319, 12, 47, "Text",
      CellTags->{"OPMatrix", "det"}],
    Cell[51726, 1739, 81, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "minor"}],
    Cell[51810, 1742, 290, 6, 66, "Text",
      CellTags->{"OPMatrix", "minor"}],
    Cell[52103, 1750, 152, 3, 44, "Input",
      CellTags->{"OPMatrix", "minor"}],
    Cell[52258, 1755, 103, 2, 44, "Input",
      CellTags->{"OPMatrix", "minor"}],
    Cell[52398, 1762, 70, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "lufac"}],
    Cell[52471, 1765, 255, 6, 66, "Text",
      CellTags->{"OPMatrix", "lufac"}],
    Cell[52729, 1773, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "lufac"}],
    Cell[52850, 1780, 71, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[52924, 1783, 346, 6, 85, "Text",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[53273, 1791, 102, 2, 44, "Input",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[53378, 1795, 108, 2, 44, "Input",
      CellTags->{"OPMatrix", "oplsol"}]},
  "enhance"->{
    Cell[42733, 1406, 94, 1, 61, "Subsection",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[42830, 1409, 169, 4, 47, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43002, 1415, 121, 3, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43126, 1420, 396, 12, 55, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43525, 1434, 68, 1, 47, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43596, 1437, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43685, 1441, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[43774, 1445, 381, 11, 66, "Text",
      CellTags->{"OPMatrix", "enhance"}],
    Cell[44158, 1458, 101, 2, 44, "Input",
      CellTags->{"OPMatrix", "enhance"}]},
  "dprod"->{
    Cell[44296, 1465, 100, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[44399, 1468, 845, 21, 104, "Text",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[45247, 1491, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "dprod"}],
    Cell[45334, 1495, 83, 2, 44, "Input",
      CellTags->{"OPMatrix", "dprod"}]},
  "circlecom"->{
    Cell[45454, 1502, 77, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "circlecom"}],
    Cell[45534, 1505, 128, 3, 47, "Text",
      CellTags->{"OPMatrix", "circlecom"}],
    Cell[45665, 1510, 94, 2, 44, "Input",
      CellTags->{"OPMatrix", "circlecom"}]},
  "complement"->{
    Cell[45796, 1517, 78, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "complement"}],
    Cell[45877, 1520, 177, 4, 47, "Text",
      CellTags->{"OPMatrix", "complement"}],
    Cell[46057, 1526, 152, 3, 44, "Input",
      CellTags->{"OPMatrix", "complement"}]},
  "diagonal"->{
    Cell[46246, 1534, 72, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "diagonal"}],
    Cell[46321, 1537, 376, 10, 66, "Text",
      CellTags->{"OPMatrix", "diagonal"}],
    Cell[46700, 1549, 86, 2, 44, "Input",
      CellTags->{"OPMatrix", "diagonal"}]},
  "gauss"->{
    Cell[46823, 1556, 88, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[46914, 1559, 531, 17, 85, "Text",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47448, 1578, 125, 2, 30, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47576, 1582, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47656, 1586, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47736, 1590, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47816, 1594, 98, 2, 44, "Input",
      CellTags->{"OPMatrix", "gauss"}],
    Cell[47917, 1598, 749, 21, 66, "Text",
      CellTags->{"OPMatrix", "gauss"}]},
  "inv"->{
    Cell[48703, 1624, 68, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "inv"}],
    Cell[48774, 1627, 388, 11, 66, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49165, 1640, 72, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49240, 1644, 391, 7, 85, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49634, 1653, 311, 7, 66, "Text",
      CellTags->{"OPMatrix", "inv"}],
    Cell[49948, 1662, 104, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50055, 1666, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50142, 1670, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}],
    Cell[50229, 1674, 83, 2, 44, "Input",
      CellTags->{"OPMatrix", "inv"}]},
  "det"->{
    Cell[50349, 1681, 124, 3, 45, "Subsection",
      CellTags->{"OPMatrix", "det"}],
    Cell[50476, 1686, 351, 11, 66, "Text",
      CellTags->{"OPMatrix", "det"}],
    Cell[50830, 1699, 76, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[50909, 1703, 77, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[50989, 1707, 273, 9, 47, "Text",
      CellTags->{"OPMatrix", "det"}],
    Cell[51265, 1718, 102, 2, 44, "Input",
      CellTags->{"OPMatrix", "det"}],
    Cell[51370, 1722, 319, 12, 47, "Text",
      CellTags->{"OPMatrix", "det"}]},
  "minor"->{
    Cell[51726, 1739, 81, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "minor"}],
    Cell[51810, 1742, 290, 6, 66, "Text",
      CellTags->{"OPMatrix", "minor"}],
    Cell[52103, 1750, 152, 3, 44, "Input",
      CellTags->{"OPMatrix", "minor"}],
    Cell[52258, 1755, 103, 2, 44, "Input",
      CellTags->{"OPMatrix", "minor"}]},
  "lufac"->{
    Cell[52398, 1762, 70, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "lufac"}],
    Cell[52471, 1765, 255, 6, 66, "Text",
      CellTags->{"OPMatrix", "lufac"}],
    Cell[52729, 1773, 84, 2, 44, "Input",
      CellTags->{"OPMatrix", "lufac"}]},
  "oplsol"->{
    Cell[52850, 1780, 71, 1, 45, "Subsection",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[52924, 1783, 346, 6, 85, "Text",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[53273, 1791, 102, 2, 44, "Input",
      CellTags->{"OPMatrix", "oplsol"}],
    Cell[53378, 1795, 108, 2, 44, "Input",
      CellTags->{"OPMatrix", "oplsol"}]},
  "Poisson"->{
    Cell[53535, 1803, 100, 1, 47, "Section",
      CellTags->"Poisson"],
    Cell[53660, 1808, 79, 1, 61, "Subsection",
      CellTags->{"Poisson", "poisson"}],
    Cell[53742, 1811, 387, 7, 85, "Text",
      CellTags->{"Poisson", "poisson"}],
    Cell[54132, 1820, 119, 3, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54254, 1825, 101, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54358, 1829, 112, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54473, 1833, 200, 4, 66, "Text",
      CellTags->{"Poisson", "poisson"}],
    Cell[54676, 1839, 98, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54811, 1846, 71, 1, 45, "Subsection",
      CellTags->{"Poisson", "setpoisson"}],
    Cell[54885, 1849, 104, 1, 47, "Text",
      CellTags->{"Poisson", "setpoisson"}],
    Cell[54992, 1852, 106, 2, 44, "Input",
      CellTags->{"Poisson", "setpoisson"}],
    Cell[55135, 1859, 77, 1, 45, "Subsection",
      CellTags->{"Poisson", "circlepoisson"}],
    Cell[55215, 1862, 209, 4, 47, "Text",
      CellTags->{"Poisson", "circlepoisson"}],
    Cell[55910, 1885, 94, 1, 45, "Subsection",
      CellTags->{"Poisson", "other"}],
    Cell[56007, 1888, 224, 5, 66, "Text",
      CellTags->{"Poisson", "other"}]},
  "poisson"->{
    Cell[53660, 1808, 79, 1, 61, "Subsection",
      CellTags->{"Poisson", "poisson"}],
    Cell[53742, 1811, 387, 7, 85, "Text",
      CellTags->{"Poisson", "poisson"}],
    Cell[54132, 1820, 119, 3, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54254, 1825, 101, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54358, 1829, 112, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}],
    Cell[54473, 1833, 200, 4, 66, "Text",
      CellTags->{"Poisson", "poisson"}],
    Cell[54676, 1839, 98, 2, 44, "Input",
      CellTags->{"Poisson", "poisson"}]},
  "setpoisson"->{
    Cell[54811, 1846, 71, 1, 45, "Subsection",
      CellTags->{"Poisson", "setpoisson"}],
    Cell[54885, 1849, 104, 1, 47, "Text",
      CellTags->{"Poisson", "setpoisson"}],
    Cell[54992, 1852, 106, 2, 44, "Input",
      CellTags->{"Poisson", "setpoisson"}]},
  "circlepoisson"->{
    Cell[55135, 1859, 77, 1, 45, "Subsection",
      CellTags->{"Poisson", "circlepoisson"}],
    Cell[55215, 1862, 209, 4, 47, "Text",
      CellTags->{"Poisson", "circlepoisson"}],
    Cell[55427, 1868, 446, 12, 55, "Input",
      CellTags->"circlepoisson"]},
  "other"->{
    Cell[55910, 1885, 94, 1, 45, "Subsection",
      CellTags->{"Poisson", "other"}],
    Cell[56007, 1888, 224, 5, 66, "Text",
      CellTags->{"Poisson", "other"}]},
  "OPSolve"->{
    Cell[56280, 1899, 61, 1, 47, "Section",
      CellTags->"OPSolve"],
    Cell[56344, 1902, 498, 12, 85, "Text",
      CellTags->"OPSolve"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"copynotice", 57604, 1938},
  {"Disclaimer", 57696, 1941},
  {"Introduction", 57931, 1948},
  {"Tour", 58095, 1953},
  {"install", 58975, 1976},
  {"load", 59152, 1981},
  {"reload", 59474, 1990},
  {"palettes", 59652, 1995},
  {"OPScalar", 59834, 2000},
  {"declare", 73038, 2313},
  {"diamond", 76232, 2390},
  {"commutator", 81731, 2521},
  {"assign", 83522, 2562},
  {"convert", 85123, 2601},
  {"order", 85651, 2614},
  {"OPMatrix", 86251, 2629},
  {"enhance", 91117, 2746},
  {"dprod", 91896, 2765},
  {"circlecom", 92250, 2774},
  {"complement", 92532, 2781},
  {"diagonal", 92816, 2788},
  {"gauss", 93091, 2795},
  {"inv", 93767, 2812},
  {"det", 94506, 2831},
  {"minor", 95089, 2846},
  {"lufac", 95438, 2855},
  {"oplsol", 95704, 2862},
  {"Poisson", 96059, 2871},
  {"poisson", 97351, 2902},
  {"setpoisson", 97959, 2917},
  {"circlepoisson", 98245, 2924},
  {"other", 98520, 2931},
  {"OPSolve", 98703, 2936}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 638, 18, 346, "Title",
  CellTags->"copynotice"],

Cell[CellGroupData[{
Cell[2402, 73, 55, 1, 67, "Section",
  CellTags->"Disclaimer"],
Cell[2460, 76, 857, 15, 199, "Text",
  CellTags->"Disclaimer"],
Cell[3320, 93, 182, 5, 47, "Text",
  CellTags->"Disclaimer"]
}, Closed]],

Cell[CellGroupData[{
Cell[3539, 103, 81, 1, 47, "Section",
  CellTags->"Introduction"],
Cell[3623, 106, 2381, 48, 389, "Text",
  CellTags->"Introduction"]
}, Closed]],

Cell[CellGroupData[{
Cell[6041, 159, 69, 1, 47, "Section",
  CellTags->"Tour"],

Cell[CellGroupData[{
Cell[6135, 164, 77, 1, 61, "Subsection",
  CellTags->{"Tour", "install"}],
Cell[6215, 167, 2189, 43, 370, "Text",
  CellTags->{"install", "Tour"}]
}, Closed]],

Cell[CellGroupData[{
Cell[8441, 215, 71, 1, 45, "Subsection",
  CellTags->{"Tour", "load"}],
Cell[8515, 218, 215, 5, 66, "Text",
  CellTags->{"load", "Tour"}],
Cell[8733, 225, 82, 2, 44, "Input",
  CellTags->{"load", "Tour"}],
Cell[8818, 229, 709, 13, 180, "Text",
  CellTags->{"load", "Tour"}]
}, Closed]],

Cell[CellGroupData[{
Cell[9564, 247, 72, 1, 45, "Subsection",
  CellTags->{"Tour", "reload"}],
Cell[9639, 250, 982, 17, 142, "Text",
  CellTags->{"Tour", "reload"}]
}, Closed]],

Cell[CellGroupData[{
Cell[10658, 272, 68, 1, 45, "Subsection",
  CellTags->{"Tour", "palettes"}],
Cell[10729, 275, 412, 9, 85, "Text",
  CellTags->{"palettes", "Tour"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11190, 290, 94, 1, 47, "Section",
  CellTags->"OPScalar"],

Cell[CellGroupData[{
Cell[11309, 295, 91, 1, 61, "Subsection",
  CellTags->{"OPScalar", "declare"}],
Cell[11403, 298, 516, 13, 66, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[11922, 313, 98, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[12023, 317, 194, 6, 47, "Text",
  CellTags->{"OPScalar", "declare"}],

Cell[CellGroupData[{
Cell[12242, 327, 101, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[12346, 331, 498, 12, 158, "Print",
  CellTags->{"OPScalar", "declare"}]
}, Open  ]],
Cell[12859, 346, 920, 24, 85, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[13782, 372, 96, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[13881, 376, 114, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[13998, 380, 428, 13, 66, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[14429, 395, 87, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[14519, 399, 152, 4, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[14674, 405, 108, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[14785, 409, 392, 14, 66, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[15180, 425, 86, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[15269, 429, 82, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[15354, 433, 188, 6, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[15545, 441, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[15636, 445, 588, 11, 104, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[16227, 458, 94, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[16324, 462, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[16416, 466, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[16508, 470, 166, 4, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[16677, 476, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[16768, 480, 255, 9, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[17026, 491, 85, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[17114, 495, 220, 7, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[17337, 504, 126, 3, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[17466, 509, 961, 23, 85, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[18430, 534, 112, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[18545, 538, 928, 28, 104, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[19476, 568, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[19568, 572, 428, 13, 66, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[19999, 587, 91, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[20093, 591, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[20184, 595, 155, 4, 47, "Text",
  CellTags->{"OPScalar", "declare"}],
Cell[20342, 601, 233, 7, 55, "Input",
  CellTags->{"OPScalar", "declare"}],
Cell[20578, 610, 105, 1, 47, "Text",
  CellTags->{"OPScalar", "declare"}]
}, Closed]],

Cell[CellGroupData[{
Cell[20720, 616, 95, 1, 45, "Subsection",
  CellTags->{"OPScalar", "diamond"}],

Cell[CellGroupData[{
Cell[20840, 621, 94, 1, 57, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[20937, 624, 505, 13, 85, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[21445, 639, 147, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[21595, 644, 322, 9, 66, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[21920, 655, 86, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[22009, 659, 766, 24, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[22778, 685, 146, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[22927, 690, 99, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[23029, 693, 356, 12, 55, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[23388, 707, 101, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[23492, 711, 285, 7, 66, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[23780, 720, 81, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[23864, 724, 479, 14, 66, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[24346, 740, 83, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[24432, 744, 249, 5, 66, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[24684, 751, 96, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[24783, 755, 70, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[24856, 758, 96, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{
Cell[24989, 765, 96, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[25088, 768, 207, 4, 66, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[25298, 774, 142, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[25443, 779, 78, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[25524, 782, 119, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[25646, 786, 238, 9, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[25887, 797, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[25979, 801, 87, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[26069, 805, 164, 4, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[26236, 811, 142, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[26381, 816, 283, 10, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[26667, 828, 154, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[26824, 833, 93, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{
Cell[26954, 840, 80, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[27037, 843, 636, 14, 104, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[27676, 859, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[27768, 863, 180, 4, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[27951, 869, 129, 3, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[28083, 874, 87, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[28173, 878, 77, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[28253, 881, 180, 4, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[28436, 887, 189, 4, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[28628, 893, 93, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[28724, 897, 91, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[28818, 900, 86, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{
Cell[28941, 907, 80, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[29024, 910, 1456, 40, 161, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[30483, 952, 110, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[30596, 956, 213, 9, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[30812, 967, 111, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[30926, 971, 158, 4, 47, "Text",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{
Cell[31121, 980, 119, 2, 43, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[31243, 984, 202, 7, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[31448, 993, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[31540, 997, 193, 6, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[31736, 1005, 86, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[31825, 1009, 94, 1, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[31922, 1012, 83, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[32008, 1016, 133, 3, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[32144, 1021, 228, 7, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[32375, 1030, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}],
Cell[32466, 1034, 313, 12, 47, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[32782, 1048, 111, 2, 44, "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]],

Cell[CellGroupData[{
Cell[32930, 1055, 85, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "diamond"}],
Cell[33018, 1058, 510, 11, 85, "Text",
  CellTags->{"OPScalar", "diamond"}],
Cell[33531, 1071, 160, 3, 44, "Input",
  CellTags->{"OPScalar", "diamond"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[33740, 1080, 88, 1, 45, "Subsection",
  CellTags->{"OPScalar", "commutator"}],

Cell[CellGroupData[{
Cell[33853, 1085, 75, 1, 57, "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],
Cell[33931, 1088, 427, 13, 66, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[34361, 1103, 172, 3, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[34536, 1108, 133, 3, 44, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[34672, 1113, 108, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[34783, 1117, 91, 1, 44, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[34877, 1120, 179, 3, 64, "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]],

Cell[CellGroupData[{
Cell[35093, 1128, 76, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],
Cell[35172, 1131, 784, 20, 85, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[35959, 1153, 87, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[36049, 1157, 102, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]],

Cell[CellGroupData[{
Cell[36188, 1164, 95, 1, 43, "Subsubsection",
  CellTags->{"OPScalar", "commutator"}],
Cell[36286, 1167, 343, 12, 66, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[36632, 1181, 95, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[36730, 1185, 79, 1, 47, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[36812, 1188, 104, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[36919, 1192, 135, 3, 47, "Text",
  CellTags->{"OPScalar", "commutator"}],
Cell[37057, 1197, 94, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}],
Cell[37154, 1201, 104, 2, 44, "Input",
  CellTags->{"OPScalar", "commutator"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37307, 1209, 106, 1, 45, "Subsection",
  CellTags->{"OPScalar", "assign"}],
Cell[37416, 1212, 158, 4, 47, "Text",
  CellTags->{"OPScalar", "assign"}],
Cell[37577, 1218, 114, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[37694, 1222, 171, 4, 47, "Text",
  CellTags->{"OPScalar", "assign"}],
Cell[37868, 1228, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[37959, 1232, 146, 4, 47, "Text",
  CellTags->{"OPScalar", "assign"}],
Cell[38108, 1238, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[38199, 1242, 121, 3, 47, "Text",
  CellTags->{"OPScalar", "assign"}],
Cell[38323, 1247, 106, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[38432, 1251, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[38523, 1255, 345, 6, 85, "Text",
  CellTags->{"OPScalar", "assign"}],
Cell[38871, 1263, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[38962, 1267, 81, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39046, 1271, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39137, 1275, 81, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39221, 1279, 89, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39313, 1283, 81, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39397, 1287, 88, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}],
Cell[39488, 1291, 81, 2, 44, "Input",
  CellTags->{"OPScalar", "assign"}]
}, Closed]],

Cell[CellGroupData[{
Cell[39606, 1298, 95, 1, 45, "Subsection",
  CellTags->{"OPScalar", "convert"}],
Cell[39704, 1301, 477, 12, 85, "Text",
  CellTags->{"OPScalar", "convert"}],
Cell[40184, 1315, 107, 2, 44, "Input",
  CellTags->{"OPScalar", "convert"}],
Cell[40294, 1319, 171, 4, 44, "Input",
  CellTags->{"OPScalar", "convert"}],
Cell[40468, 1325, 295, 12, 33, "Text",
  CellTags->{"OPScalar", "convert"}],
Cell[40766, 1339, 170, 4, 30, "Input",
  CellTags->{"OPScalar", "convert"}]
}, Closed]],

Cell[CellGroupData[{
Cell[40973, 1348, 71, 1, 45, "Subsection",
  CellTags->{"OPScalar", "order"}],
Cell[41047, 1351, 310, 10, 66, "Text",
  CellTags->{"OPScalar", "order"}],
Cell[41360, 1363, 163, 4, 44, "Input",
  CellTags->{"OPScalar", "order"}],
Cell[41526, 1369, 483, 8, 85, "Text",
  CellTags->{"OPScalar", "order"}],
Cell[42012, 1379, 140, 3, 44, "Input",
  CellTags->{"OPScalar", "order"}],
Cell[42155, 1384, 218, 5, 47, "Text",
  CellTags->{"OPScalar", "order"}],
Cell[42376, 1391, 189, 4, 44, "Input",
  CellTags->{"OPScalar", "order"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42614, 1401, 94, 1, 47, "Section",
  CellTags->"OPMatrix"],

Cell[CellGroupData[{
Cell[42733, 1406, 94, 1, 61, "Subsection",
  CellTags->{"OPMatrix", "enhance"}],
Cell[42830, 1409, 169, 4, 47, "Text",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43002, 1415, 121, 3, 44, "Input",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43126, 1420, 396, 12, 55, "Input",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43525, 1434, 68, 1, 47, "Text",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43596, 1437, 86, 2, 44, "Input",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43685, 1441, 86, 2, 44, "Input",
  CellTags->{"OPMatrix", "enhance"}],
Cell[43774, 1445, 381, 11, 66, "Text",
  CellTags->{"OPMatrix", "enhance"}],
Cell[44158, 1458, 101, 2, 44, "Input",
  CellTags->{"OPMatrix", "enhance"}]
}, Closed]],

Cell[CellGroupData[{
Cell[44296, 1465, 100, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "dprod"}],
Cell[44399, 1468, 845, 21, 104, "Text",
  CellTags->{"OPMatrix", "dprod"}],
Cell[45247, 1491, 84, 2, 44, "Input",
  CellTags->{"OPMatrix", "dprod"}],
Cell[45334, 1495, 83, 2, 44, "Input",
  CellTags->{"OPMatrix", "dprod"}]
}, Closed]],

Cell[CellGroupData[{
Cell[45454, 1502, 77, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "circlecom"}],
Cell[45534, 1505, 128, 3, 47, "Text",
  CellTags->{"OPMatrix", "circlecom"}],
Cell[45665, 1510, 94, 2, 44, "Input",
  CellTags->{"OPMatrix", "circlecom"}]
}, Closed]],

Cell[CellGroupData[{
Cell[45796, 1517, 78, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "complement"}],
Cell[45877, 1520, 177, 4, 47, "Text",
  CellTags->{"OPMatrix", "complement"}],
Cell[46057, 1526, 152, 3, 44, "Input",
  CellTags->{"OPMatrix", "complement"}]
}, Closed]],

Cell[CellGroupData[{
Cell[46246, 1534, 72, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "diagonal"}],
Cell[46321, 1537, 376, 10, 66, "Text",
  CellTags->{"OPMatrix", "diagonal"}],
Cell[46700, 1549, 86, 2, 44, "Input",
  CellTags->{"OPMatrix", "diagonal"}]
}, Closed]],

Cell[CellGroupData[{
Cell[46823, 1556, 88, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "gauss"}],
Cell[46914, 1559, 531, 17, 85, "Text",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47448, 1578, 125, 2, 30, "Input",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47576, 1582, 77, 2, 44, "Input",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47656, 1586, 77, 2, 44, "Input",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47736, 1590, 77, 2, 44, "Input",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47816, 1594, 98, 2, 44, "Input",
  CellTags->{"OPMatrix", "gauss"}],
Cell[47917, 1598, 749, 21, 66, "Text",
  CellTags->{"OPMatrix", "gauss"}]
}, Closed]],

Cell[CellGroupData[{
Cell[48703, 1624, 68, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "inv"}],
Cell[48774, 1627, 388, 11, 66, "Text",
  CellTags->{"OPMatrix", "inv"}],
Cell[49165, 1640, 72, 2, 44, "Input",
  CellTags->{"OPMatrix", "inv"}],
Cell[49240, 1644, 391, 7, 85, "Text",
  CellTags->{"OPMatrix", "inv"}],
Cell[49634, 1653, 311, 7, 66, "Text",
  CellTags->{"OPMatrix", "inv"}],
Cell[49948, 1662, 104, 2, 44, "Input",
  CellTags->{"OPMatrix", "inv"}],
Cell[50055, 1666, 84, 2, 44, "Input",
  CellTags->{"OPMatrix", "inv"}],
Cell[50142, 1670, 84, 2, 44, "Input",
  CellTags->{"OPMatrix", "inv"}],
Cell[50229, 1674, 83, 2, 44, "Input",
  CellTags->{"OPMatrix", "inv"}]
}, Closed]],

Cell[CellGroupData[{
Cell[50349, 1681, 124, 3, 45, "Subsection",
  CellTags->{"OPMatrix", "det"}],
Cell[50476, 1686, 351, 11, 66, "Text",
  CellTags->{"OPMatrix", "det"}],
Cell[50830, 1699, 76, 2, 44, "Input",
  CellTags->{"OPMatrix", "det"}],
Cell[50909, 1703, 77, 2, 44, "Input",
  CellTags->{"OPMatrix", "det"}],
Cell[50989, 1707, 273, 9, 47, "Text",
  CellTags->{"OPMatrix", "det"}],
Cell[51265, 1718, 102, 2, 44, "Input",
  CellTags->{"OPMatrix", "det"}],
Cell[51370, 1722, 319, 12, 47, "Text",
  CellTags->{"OPMatrix", "det"}]
}, Closed]],

Cell[CellGroupData[{
Cell[51726, 1739, 81, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "minor"}],
Cell[51810, 1742, 290, 6, 66, "Text",
  CellTags->{"OPMatrix", "minor"}],
Cell[52103, 1750, 152, 3, 44, "Input",
  CellTags->{"OPMatrix", "minor"}],
Cell[52258, 1755, 103, 2, 44, "Input",
  CellTags->{"OPMatrix", "minor"}]
}, Closed]],

Cell[CellGroupData[{
Cell[52398, 1762, 70, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "lufac"}],
Cell[52471, 1765, 255, 6, 66, "Text",
  CellTags->{"OPMatrix", "lufac"}],
Cell[52729, 1773, 84, 2, 44, "Input",
  CellTags->{"OPMatrix", "lufac"}]
}, Closed]],

Cell[CellGroupData[{
Cell[52850, 1780, 71, 1, 45, "Subsection",
  CellTags->{"OPMatrix", "oplsol"}],
Cell[52924, 1783, 346, 6, 85, "Text",
  CellTags->{"OPMatrix", "oplsol"}],
Cell[53273, 1791, 102, 2, 44, "Input",
  CellTags->{"OPMatrix", "oplsol"}],
Cell[53378, 1795, 108, 2, 44, "Input",
  CellTags->{"OPMatrix", "oplsol"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[53535, 1803, 100, 1, 47, "Section",
  CellTags->"Poisson"],

Cell[CellGroupData[{
Cell[53660, 1808, 79, 1, 61, "Subsection",
  CellTags->{"Poisson", "poisson"}],
Cell[53742, 1811, 387, 7, 85, "Text",
  CellTags->{"Poisson", "poisson"}],
Cell[54132, 1820, 119, 3, 44, "Input",
  CellTags->{"Poisson", "poisson"}],
Cell[54254, 1825, 101, 2, 44, "Input",
  CellTags->{"Poisson", "poisson"}],
Cell[54358, 1829, 112, 2, 44, "Input",
  CellTags->{"Poisson", "poisson"}],
Cell[54473, 1833, 200, 4, 66, "Text",
  CellTags->{"Poisson", "poisson"}],
Cell[54676, 1839, 98, 2, 44, "Input",
  CellTags->{"Poisson", "poisson"}]
}, Closed]],

Cell[CellGroupData[{
Cell[54811, 1846, 71, 1, 45, "Subsection",
  CellTags->{"Poisson", "setpoisson"}],
Cell[54885, 1849, 104, 1, 47, "Text",
  CellTags->{"Poisson", "setpoisson"}],
Cell[54992, 1852, 106, 2, 44, "Input",
  CellTags->{"Poisson", "setpoisson"}]
}, Closed]],

Cell[CellGroupData[{
Cell[55135, 1859, 77, 1, 45, "Subsection",
  CellTags->{"Poisson", "circlepoisson"}],
Cell[55215, 1862, 209, 4, 47, "Text",
  CellTags->{"Poisson", "circlepoisson"}],
Cell[55427, 1868, 446, 12, 55, "Input",
  CellTags->"circlepoisson"]
}, Closed]],

Cell[CellGroupData[{
Cell[55910, 1885, 94, 1, 45, "Subsection",
  CellTags->{"Poisson", "other"}],
Cell[56007, 1888, 224, 5, 66, "Text",
  CellTags->{"Poisson", "other"}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[56280, 1899, 61, 1, 47, "Section",
  CellTags->"OPSolve"],
Cell[56344, 1902, 498, 12, 85, "Text",
  CellTags->"OPSolve"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

